#### Parent port

Select exactly one port as the parent port of the trunk to be created. Mandatory.

Loading ports... Please Wait

| Name | IP | Admin State | Status |
--- | --- | --- | --- | --- | ---
Select an item from Available items below
| {$ ctrl.nameOrID(item) $} | {$ address $} on subnet {$ subnet $} | {$ item.admin_state | decode:ctrl.portAdminStates $} | {$ item.status | decode:ctrl.portStatuses $} |
ID {$ item.id $} Project ID {$ item.tenant_id $} Network ID {$ item.network_id $} Network {$ item.network_name $} MAC Address {$ item.mac_address $} Device Owner {$ item.device_owner $} Device ID {$ item.device_id $} VNIC type {$ item['binding:vnic_type'] | decode:ctrl.vnicTypes $} Host ID {$ item['binding:host_id'] $}

| Name | IP | Admin State | Status |
--- | --- | --- | --- | --- | ---
No available items
| {$ ctrl.nameOrID(item) $} | {$ address $} on subnet {$ subnet $} | {$ item.admin_state | decode:ctrl.portAdminStates $} | {$ item.status | decode:ctrl.portStatuses $} |
ID {$ item.id $} Project ID {$ item.tenant_id $} Network ID {$ item.network_id $} Network {$ item.network_name $} MAC Address {$ item.mac_address $} Device ID {$ item.device_id $} VNIC type {$ item['binding:vnic_type'] | decode:ctrl.vnicTypes $} Host ID {$ item['binding:host_id'] $}